uniform vec4 specular;
uniform vec4 diffuse;
uniform vec4 ambient;
uniform float n_specular;
uniform vec4 lightDir;

varying vec2  vTexCoord;
varying vec4  vDiffuse;
varying vec4  vSpecular;


void main(void)
{   
   // Output transformed vertex position: - stavi ga u lokalni 3d prostor
   // odnosno transfoirmira svaki verteks
   gl_Position = gl_ModelViewProjectionMatrix * gl_Vertex;

   // Compute the light vector (view space):
   vec3 vecLight = -lightDir.xyz;
   vecLight.z    = -vecLight.z;    // notice that we need to flip the z here to let OGL match D3D

   // Transform vertex position into view space:
   vec3 Pview =  vec3(gl_ModelViewMatrix * gl_Vertex);

   // Transform normal into view space:        
   vec3 vecNormal = normalize( gl_NormalMatrix * gl_Normal);

   // Compute reflection vector (view space):
   // tu se racuna neki vektor koji se odbija pod istim kutem pod kojim upada na normalu
   vec3 vecReflect = normalize( 2.0 * dot( vecNormal, vecLight ) * vecNormal - vecLight );         

   // Compute view vector (view space):
   vec3 vecView = -normalize(Pview);                
   
   // Compute diffuse and ambient contribution: 
   vDiffuse = ambient + diffuse * 0.8 * max(0.0, dot(vecNormal, vecLight)); 

   // Compute specular term:
   vSpecular = specular * pow(max(0.0, dot(vecReflect, vecView)), n_specular);    

   // Propagate texture coordinates:
   vTexCoord = vec2(gl_MultiTexCoord0);
   
}